/*
 * JConsoleTester.java - Test application for JConsole
 *
 * Copyright (c) 2004,2005 Gregory Kotsaftis
 * gregkotsaftis@yahoo.com
 * http://zeus-jscl.sourceforge.net/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */
package gr.zeus.tests;

import gr.zeus.ui.JConsole;
import gr.zeus.util.GUIUtils;
import javax.swing.JFrame;
import javax.swing.JOptionPane;
import javax.swing.UIManager;


public class JConsoleTester extends JFrame {
    
    // create a single instance to the console for our application
    private static JConsole s_console = JConsole.getConsole();
    
    private boolean m_realExit = true;
    
    
    public JConsoleTester()
    {
        init_lnf();
        
        initComponents();
        
        init_console();
        
        GUIUtils.centerOnScreen( this );
    }
    
    
    /**
     * Just to be able to use the JTester which is a wrapper for all
     * the demos. If we use the JTester we also setExitMode( false ),
     * else the default is for each individual test to System.exit()
     * by it's own...
     */
    public void setExitMode(boolean exit)
    {
        m_realExit = exit;
    }
    
    
    /** This method is called from within the constructor to
     * initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is
     * always regenerated by the Form Editor.
     */
    private void initComponents()//GEN-BEGIN:initComponents
    {
        javax.swing.JMenuItem consoleMenuItem;
        javax.swing.JButton errorButton;
        javax.swing.JMenuItem errorExitMenuItem;
        javax.swing.JButton exceptionButton;
        javax.swing.JMenu fileMenu;
        javax.swing.JButton helloButton;
        javax.swing.JMenuBar menuBar;
        javax.swing.JMenuItem normalExitMenuItem;
        javax.swing.JPanel panel1;

        panel1 = new javax.swing.JPanel();
        helloButton = new javax.swing.JButton();
        errorButton = new javax.swing.JButton();
        exceptionButton = new javax.swing.JButton();
        menuBar = new javax.swing.JMenuBar();
        fileMenu = new javax.swing.JMenu();
        consoleMenuItem = new javax.swing.JMenuItem();
        errorExitMenuItem = new javax.swing.JMenuItem();
        normalExitMenuItem = new javax.swing.JMenuItem();

        setDefaultCloseOperation(javax.swing.WindowConstants.DO_NOTHING_ON_CLOSE);
        setTitle("Sample Application to demonstrate JConsole");
        helloButton.setText("hello");
        helloButton.addActionListener(new java.awt.event.ActionListener()
        {
            public void actionPerformed(java.awt.event.ActionEvent evt)
            {
                helloButtonActionPerformed(evt);
            }
        });

        panel1.add(helloButton);

        errorButton.setText("error");
        errorButton.addActionListener(new java.awt.event.ActionListener()
        {
            public void actionPerformed(java.awt.event.ActionEvent evt)
            {
                errorButtonActionPerformed(evt);
            }
        });

        panel1.add(errorButton);

        exceptionButton.setText("exception");
        exceptionButton.addActionListener(new java.awt.event.ActionListener()
        {
            public void actionPerformed(java.awt.event.ActionEvent evt)
            {
                exceptionButtonActionPerformed(evt);
            }
        });

        panel1.add(exceptionButton);

        getContentPane().add(panel1, java.awt.BorderLayout.CENTER);

        fileMenu.setText("File");
        consoleMenuItem.setText("Show Console");
        consoleMenuItem.addActionListener(new java.awt.event.ActionListener()
        {
            public void actionPerformed(java.awt.event.ActionEvent evt)
            {
                consoleMenuItemActionPerformed(evt);
            }
        });

        fileMenu.add(consoleMenuItem);

        errorExitMenuItem.setText("Exit with error code");
        errorExitMenuItem.addActionListener(new java.awt.event.ActionListener()
        {
            public void actionPerformed(java.awt.event.ActionEvent evt)
            {
                errorExitMenuItemActionPerformed(evt);
            }
        });

        fileMenu.add(errorExitMenuItem);

        normalExitMenuItem.setText("Normal Exit");
        normalExitMenuItem.addActionListener(new java.awt.event.ActionListener()
        {
            public void actionPerformed(java.awt.event.ActionEvent evt)
            {
                normalExitMenuItemActionPerformed(evt);
            }
        });

        fileMenu.add(normalExitMenuItem);

        menuBar.add(fileMenu);

        setJMenuBar(menuBar);

        pack();
    }//GEN-END:initComponents

    private void exceptionButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_exceptionButtonActionPerformed
        
        // fake an exception
        String numS = "this is not a number!";
        int num = Integer.parseInt( numS ); // this will raise an runtime exception
        System.out.println("num=" + num);   // actually never executed...
        
    }//GEN-LAST:event_exceptionButtonActionPerformed

    private void errorButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_errorButtonActionPerformed
        
        System.err.println("Hello new stderr!");
        
    }//GEN-LAST:event_errorButtonActionPerformed

    private void helloButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_helloButtonActionPerformed
        
        System.out.println("Hello new stdout!");
        
    }//GEN-LAST:event_helloButtonActionPerformed

    private void normalExitMenuItemActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_normalExitMenuItemActionPerformed
        
        myExit( 0 );
        
    }//GEN-LAST:event_normalExitMenuItemActionPerformed

    private void errorExitMenuItemActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_errorExitMenuItemActionPerformed
        
        myExit( 1 );
        
    }//GEN-LAST:event_errorExitMenuItemActionPerformed

    private void consoleMenuItemActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_consoleMenuItemActionPerformed
        
        s_console.showConsole();
        
    }//GEN-LAST:event_consoleMenuItemActionPerformed
    
    
    /**
     * setup our look and feel
     */
    private void init_lnf()
    {
        try
        {
            UIManager.setLookAndFeel( UIManager.getSystemLookAndFeelClassName() );

            // NOTE: since the JConsole is actually a singleton, if we use
            // any LOOK & FEEL other than the default, we also need to invoke
            // this method to update the console's lnf...
            s_console.updateLNF();
        }
        catch( Exception e )
        {
            System.err.println("Cannot initialize the look & feel");
            
            e.printStackTrace();
        }
    }
    
    
    /**
     * configure and start the JConsole
     */
    private void init_console()
    {
        // just to demonstrate we are about to redirect the streams...
        System.out.println("Hello and goodbye from stdout");
        System.err.println("Hello and goodbye from stderr");
        
        // if you want to modify the text/buttons/title/etc of JConsole,
        // or force it to autosave and clear the console's messages
        // you can do it here ... before starting the console!
        s_console.setAppendFirstTime( false );
        s_console.setAutoSave( true );
        
        // clear the console messages (only the textarea) when maxchars are
        // reached, because a lot of messages can slow down the textarea panel.
        //s_console.setMaxChars( 10 * 1024 );
        
        // finally start the console
        s_console.startConsole();
        
        // demonstrate that our console is up and running...
        System.out.println("This is the very first message logged to JConsole (stdout)");
        System.err.println("This is the very first message logged to JConsole (stderr)");
    }
  
    
    /**
     * provide our own exit() method in order to be able to
     * save the trace file when our application aborts it's normal
     * execution and we don't have the time to see the JConsole for
     * error details...
     */
    private void myExit(int code)
    {
        if( code!=0 )
        {
            // dump all messages printed to a new logfile if you wish!
            s_console.dumpConsole("dump.log", false);
            
            JOptionPane.showMessageDialog(
                this,
                "Application Error!" + "\n" + "Check dump.log for details!",
                "Fatal Error Occured",
                JOptionPane.ERROR_MESSAGE);
        }
        
        // actually not really needed if we are to invoke exit() next...
        s_console.destroyConsole();
        
        // ...just to demonstrate the actual restore of stdout, stderr
        System.out.println("Hello again from stdout");
        System.err.println("Hello again from stderr");
        
        if( m_realExit )
        {
            System.exit( code );
        }
        else
        {
            setVisible( false );
            dispose();
        }
    }
    
    
    /**
     * @param args the command line arguments
     */
    public static void main(String args[])
    {
        java.awt.EventQueue.invokeLater(new Runnable() {
            public void run() {
                new JConsoleTester().setVisible(true);
            }
        });
    }
    
    // Variables declaration - do not modify//GEN-BEGIN:variables
    // End of variables declaration//GEN-END:variables
    
}
