/*
 * JTableSortTester.java - Test application for TableSorter and related classes
 *
 * Copyright (c) 2004,2005 Gregory Kotsaftis
 * gregkotsaftis@yahoo.com
 * http://zeus-jscl.sourceforge.net/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */
package gr.zeus.tests;

import gr.zeus.ui.table.ProgressBarCellRenderer;
import gr.zeus.ui.table.sort.SortButtonHeaderListener;
import gr.zeus.ui.table.sort.SortButtonRenderer;
import gr.zeus.ui.table.sort.SortableTableModel;
import java.awt.Color;
import java.text.SimpleDateFormat;
import java.util.Hashtable;
import javax.swing.JFrame;
import javax.swing.table.JTableHeader;
import javax.swing.table.TableColumnModel;


public class JTableSortTester extends JFrame {
    
    private static final String[] COLUMN_NAMES = {"DATE", "INTEGER", "STRING", "FLOAT", "BOOLEAN", "PROGRESS"};
    
    private SortableTableModel m_tableModel = new SortableTableModel(null, COLUMN_NAMES) {

        public boolean isCellEditable(int row, int column)
        {
            return( true );
        }
        
        public Class getColumnClass(int mColIndex)
        {
            int rowIndex = 0;
            Object o = getValueAt(rowIndex, mColIndex);
            if( o == null )
            {
                return( Object.class );
            }
            else
            {
                return( o.getClass() );
            }
        }
    };
    
    
    public JTableSortTester()
    {
        initComponents();
        
        // config table
        m_table.setModel( m_tableModel );
        //m_table.getTableHeader().setReorderingAllowed( false );

        // configuration for sorting...
        m_table.setAutoCreateColumnsFromModel( false );
        SortButtonRenderer renderer1 = new SortButtonRenderer();        
        SortButtonRenderer renderer2 = new SortButtonRenderer(
            SortButtonRenderer.EMPTY_ICON, SortButtonRenderer.UP1_ICON, SortButtonRenderer.DOWN1_ICON);        
        SortButtonRenderer renderer3 = new SortButtonRenderer(
            SortButtonRenderer.EMPTY_ICON, SortButtonRenderer.UP2_ICON, SortButtonRenderer.DOWN2_ICON);
        SortButtonRenderer renderer4 = new SortButtonRenderer(
            SortButtonRenderer.EMPTY_ICON, SortButtonRenderer.UP3_ICON, SortButtonRenderer.DOWN3_ICON);        
        TableColumnModel model = m_table.getColumnModel();
        model.getColumn(0).setHeaderRenderer(renderer1);
        model.getColumn(1).setHeaderRenderer(renderer2);
        model.getColumn(2).setHeaderRenderer(renderer3);
        model.getColumn(3).setHeaderRenderer(renderer4);
        model.getColumn(4).setHeaderRenderer(renderer1);
        model.getColumn(5).setHeaderRenderer(renderer2);
        JTableHeader header = m_table.getTableHeader();
        header.addMouseListener(new SortButtonHeaderListener(header, renderer1));
        header.addMouseListener(new SortButtonHeaderListener(header, renderer2));
        header.addMouseListener(new SortButtonHeaderListener(header, renderer3));
        header.addMouseListener(new SortButtonHeaderListener(header, renderer4));
        
        // configuration for progress bar...
        Hashtable<Integer,Color> limitColors = new Hashtable<Integer,Color>();
        limitColors.put(new Integer( 0), Color.green);
        limitColors.put(new Integer(60), Color.yellow);
        limitColors.put(new Integer(80), Color.red);
        model.getColumn(5).setCellRenderer( new ProgressBarCellRenderer(true,false,0,100,limitColors,m_table.getBackground()) );
        
        // add data
        try
        {
            SimpleDateFormat sdf = new SimpleDateFormat("dd/MM/yyyy");
            Object[][] values = new Object[][]
            {
                {sdf.parse("12/5/2004"), new Integer(10), "greg", new Float(10.25F), Boolean.FALSE, new Integer(0)},
                {sdf.parse("11/05/2004"), new Integer(11), "litsa", new Float(23.26F), Boolean.TRUE, new Integer(10)},
                {sdf.parse("20/7/2004"), new Integer(9), "geo", new Float(109.32F), Boolean.TRUE, new Integer(25)},
                {sdf.parse("30/10/1999"), new Integer(190), "kostas", new Float(23.27F), Boolean.FALSE, new Integer(50)},
                {sdf.parse("5/3/2001"), new Integer(910), "spyros", new Float(410.00F), Boolean.FALSE, new Integer(75)},
                {sdf.parse("6/04/2000"), new Integer(5), "malakas", new Float(23.25F), Boolean.TRUE, new Integer(100)}
            };
            /*m_tableModel.addRow(values[0]);
            m_tableModel.addRow(values[1]);
            m_tableModel.addRow(values[2]);
            m_tableModel.addRow(values[3]);
            m_tableModel.addRow(values[4]);
            m_tableModel.addRow(values[5]);*/
            m_tableModel.setDataVector(values, COLUMN_NAMES);
        }
        catch(Exception e)
        {
            e.printStackTrace();            
        }
    }

    
    /** This method is called from within the constructor to
     * initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is
     * always regenerated by the Form Editor.
     */
    private void initComponents()//GEN-BEGIN:initComponents
    {
        javax.swing.JScrollPane jScrollPane1;

        jScrollPane1 = new javax.swing.JScrollPane();
        m_table = new javax.swing.JTable();

        setDefaultCloseOperation(javax.swing.WindowConstants.EXIT_ON_CLOSE);
        m_table.setModel(new javax.swing.table.DefaultTableModel(
            new Object [][]
            {

            },
            new String []
            {
                "Title 1", "Title 2", "Title 3", "Title 4", "Title 5", "Title 6"
            }
        ));
        jScrollPane1.setViewportView(m_table);

        getContentPane().add(jScrollPane1, java.awt.BorderLayout.CENTER);

        pack();
    }//GEN-END:initComponents
    

    /**
     * @param args the command line arguments
     */
    public static void main(String args[])
    {
        java.awt.EventQueue.invokeLater(new Runnable() {
            public void run() {
                new JTableSortTester().setVisible(true);
            }
        });
    }
    
    
    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JTable m_table;
    // End of variables declaration//GEN-END:variables
    
}
