/*
 * BlankIcon.java
 *
 * Copyright (c) 2004,2005 Gregory Kotsaftis
 * gregkotsaftis@yahoo.com
 * http://zeus-jscl.sourceforge.net/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */
package gr.zeus.ui.table.sort;

import java.awt.Color;
import java.awt.Component;
import java.awt.Graphics;
import javax.swing.Icon;

/**
 * Empty icon for table header for <code>TableSorter</code>. Original code from:
 * <a href="http://www.senun.com/Left/Programming/Java_old/Examples_swing/SwingExamples.html">
 * http://www.senun.com/Left/Programming/Java_old/Examples_swing/SwingExamples.html</a>
 * <p>
 * @author Gregory Kotsaftis
 * @since 1.02
 */
public final class BlankIcon implements Icon {

    /**
     * Default icon size.
     */
    private static final int DEFAULT_SIZE = 11;
    
    /**
     * Fill color.
     */
    private Color m_fillColor;

    /**
     * Size.
     */
    private int m_size;

    
    /**
     * Constructor.
     */
    public BlankIcon()
    {
        this(null, DEFAULT_SIZE);
    }

    
    /**
     * Constructor.
     * <p>
     * @param color     The fill <code>Color</code>.
     * @param size      The size.
     */
    public BlankIcon(Color color, int size)
    {
        //UIManager.getColor("control")
        //UIManager.getColor("controlShadow")
        m_fillColor = color;

        m_size = size;    
    }

    
    /**
     * Paints the icon.
     * <p>
     * @param c     The <code>Component</code>.
     * @param g     The <code>Graphics</code> to use.
     * @param x     The x location.
     * @param y     The y location.
     */
    public void paintIcon(Component c, Graphics g, int x, int y)
    {
        if( m_fillColor != null )
        {
            g.setColor(m_fillColor);
            g.drawRect(x, y, m_size-1, m_size-1);
        }
    }

    
    /**
     * Gets the icon's width.
     * <p>
     * @return  The icon's width.
     */
    public int getIconWidth()
    {
        return( m_size );
    }

    
    /**
     * Gets the icon's height.
     * <p>
     * @return  The icon's height.
     */
    public int getIconHeight()
    {
        return( m_size );
    }
    
}
