/*
 * TableSorter.java
 *
 * Copyright (c) 2004,2005 Gregory Kotsaftis
 * gregkotsaftis@yahoo.com
 * http://zeus-jscl.sourceforge.net/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */
package gr.zeus.ui.table.sort;

/**
 * JTable sorter. Original code from:
 * <a href="http://www.senun.com/Left/Programming/Java_old/Examples_swing/SwingExamples.html">
 * http://www.senun.com/Left/Programming/Java_old/Examples_swing/SwingExamples.html</a>
 * <p>
 * @author Gregory Kotsaftis
 * @since 1.02
 */
public final class TableSorter {

    /**
     * Instance of <code>SortableTableModel</code>.
     */
    private SortableTableModel m_model;

    
    /**
     * Constructor.
     * <p>
     * @param model     Instance of <code>SortableTableModel</code>.
     */
    public TableSorter(SortableTableModel model)
    {
        m_model = model;
    }

    
    /**
     * n2 selection.
     * <p>
     * @param column    The column to sort.
     * @param isAscent  Check if ascending.
     */
    public void sort(int column, boolean isAscent)
    {
        int n = m_model.getRowCount();
        int[] indexes = m_model.getIndexes();   
    
        for(int i=0; i<n-1; i++)
        {
            int k = i;
            for(int j=i+1; j<n; j++)
            {
                if( isAscent )
                {
                    if( compare(column, j, k) < 0 )
                    {
                        k = j;
                    }
                }
                else
                {
                    if( compare(column, j, k) > 0 )
                    {
                        k = j;
                    }
                }
            }

            int tmp = indexes[i];
            indexes[i] = indexes[k];
            indexes[k] = tmp;
        }
    }


    /**
     * Comparaters.
     * <p>
     * @param column    The column number.
     * @param row1      The first row number to compare.
     * @param row2      The second row number to compare.
     * <p>
     * @return          Higher or lower number by comparison.
     */
    public int compare(int column, int row1, int row2)
    {
        Object o1 = m_model.getValueAt(row1, column);
        Object o2 = m_model.getValueAt(row2, column); 
        if( o1 == null && o2 == null )
        {
            return( 0 );
        }
        else if( o1 == null )
        {
            return( -1 );
        }
        else if( o2 == null )
        { 
            return( 1 );
        }
        else
        {   
            Class type = m_model.getColumnClass( column );
            
            if( type.getSuperclass() == Number.class )
            {
                return( compare((Number)o1, (Number)o2) );
            }
            else if( type == String.class )
            {
                return( ((String)o1).compareTo((String)o2) );
            }
            else if( type == java.util.Date.class )
            {
                return( compare((java.util.Date)o1, (java.util.Date)o2) );
            }
            else if( type == Boolean.class )
            {
                return( compare((Boolean)o1, (Boolean)o2) );
            }
            else
            {
                return( ((String)o1).compareTo((String)o2) );
            }
        }
        
    }

    
    /**
     * Compares two numbers for higher or lower values.
     * <p>
     * @param o1    The first <code>Number</code>.
     * @param o2    The second <code>Number</code>.
     * <p>
     * @return      0, 1 or -1 depending on the result.
     */
    public int compare(Number o1, Number o2)
    {
        double n1 = o1.doubleValue();
        double n2 = o2.doubleValue();
        
        if( n1 < n2 )
        {
            return( -1 );
        }
        else if( n1 > n2 )
        {
            return( 1 );
        }
        else
        {
            return( 0 );
        }
    }

    
    /**
     * Compares two dates.
     * <p>
     * @param o1    The first <code>Date</code>.
     * @param o2    The second <code>Date</code>.
     * <p>
     * @return      0, 1 or -1 depending on the result.
     */
    public int compare(java.util.Date o1, java.util.Date o2)
    {
        long n1 = o1.getTime();
        long n2 = o2.getTime();
        
        if( n1 < n2 )
        {
            return( -1 );
        }
        else if( n1 > n2 )
        {
            return( 1 );
        }
        else
        {
            return( 0 );
        }
    }

    
    /**
     * Compares two <code>boolean</code> values.
     * <p>
     * @param o1    The first <code>Boolean</code>.
     * @param o2    The second <code>Boolean</code>.
     * <p>
     * @return      0, 1 or -1 depending on the result.
     */
    public int compare(Boolean o1, Boolean o2)
    {
        boolean b1 = o1.booleanValue();
        boolean b2 = o2.booleanValue();
        
        if( b1 == b2 )
        {
            return( 0 );
        }
        else if( b1==true )
        {
            return( 1 );
        }
        else
        {
            return( -1 );
        }
    }
  
}
